@@ -638,7 +638,7 @@ class EventVariable(Variable[EventValue]):
         if value:
             return '1' + self.ident
         else:
-            raise ValueError('invalid event value')
+            raise ValueError('Invalid event value')
 
     def dump(self, check: bool = True) -> Optional[str]:
         return None
@@ -664,11 +664,20 @@ class StringVariable(Variable[StringValue]):
 
         """
         if value is None:
-            value = ''
-        if check and (not isinstance(value, str) or ' ' in value):
-            raise ValueError(f'Invalid string value ({value})')
-
-        return f's{value} {self.ident}'
+            value_str = ''
+        elif check and not isinstance(value, str):
+            raise ValueError(f'Invalid string value ({value!r})')
+        else:
+            value_str = value.translate(
+                {
+                    9: "\\t",
+                    10: "\\n",
+                    13: "\\r",
+                    32: "\\x20",
+                    92: "\\\\",
+                }
+            )
+        return f's{value_str} {self.ident}'
 
 
 class RealVariable(Variable[RealValue]):
